C     ----------------------------------------------------
      SUBROUTINE LAND(IUSER,NUSER,ICMO,AREA,DUSER,RUSER,
     1   ETUSER,PUSER,ROOT,THETA0,CLOSS,TAILF,THAWC,GAMMA,
     2   UCOEF,RECH,IOUT,EVAP)
C     ----------------------------------------------------
C
      INCLUDE 'PARAM2.FOR'
      IMPLICIT INTEGER*2 (I-N)
      REAL THETA(MAXUSE,5)
C
C     COMPUTE GW RECHARGE, ET, AND SOIL MOISTURE
C
C     THAWC   AVAILABLE WATER CAPACITY OF SOIL=FIELD CAPACITY-WILTING POINT
C     DRECH   GROUND WATER RECHARGE
C     GAMMA   CRITICAL SOIL MOISTURE
C     PET     POTENTIAL EVAPOTRANSPIRATION FOR USER
C     PPT     PRECIPITATION (INCHES)
C     PPTEFF  EFFECTIVE PRECIPITATION
C     PUSER   PUMPED IRRIGATION WATER
C     RETFLO  RETURN FLOW FROM APPLIED WATER AND PRECIP FOR USER
C     THETA0  INITIAL SOIL MOISTURE FOR USER, REFERENCED TO WILTING POINT
C     THETA   SOIL MOISTURE PER USER, PER ZONE, REFERNCED TO WILTING POINT
C     UCOEF   UNIFORMITY COEFFICIENT FOR DISTRIBUTING APPLIED WATER
C     TAILF   TAILWATER FACTOR FOR SURFACE RUNOFF FROM FIELD FURROWS
C
C     INITIALIZE MASS BALANCE CHECKS FOR MONTH
C
      IF (IUSER.EQ.1) THEN
      XPPT=0.0
      XPUMP=0.0
      XCANAL=0.0
      XDP=0.0
      XTAIL=0.0
      XRO=0.0
      XET=0.0
      XDS=0.0
      ENDIF
C
C     INITIALIZE SOIL MOISTURE FOR EACH ZONE
C
      IF (ICMO.EQ.1) THEN
      SXRES=0.0
      DO 120 IZONE=1,5
      THETA(IUSER,IZONE)=THETA0
 120  CONTINUE
      ENDIF
C
C     USE USBR METHOD TO COMPUTE EFFECTIVE PRECIPITATION
C
      PPT=RUSER*12.0
      IF (PPT.LT.1.0) THEN
      PPTEFF=PPT*0.95
      GO TO 130
      ELSE
      PPTEFF=0.95
      PPT=PPT-1.0
      ENDIF
      IF (PPT.LT.1.0) THEN
      PPTEFF=PPTEFF+PPT*0.90
      GO TO 130
      ELSE
      PPTEFF=PPTEFF+0.90
      PPT=PPT-1.0
      ENDIF
      IF (PPT.LT.1.0) THEN
      PPTEFF=PPTEFF+PPT*0.825
      GO TO 130
      ELSE
      PPTEFF=PPTEFF+0.825
      PPT=PPT-1.0
      ENDIF
      IF (PPT.LT.1.0) THEN
      PPTEFF=PPTEFF+PPT*0.65
      GO TO 130
      ELSE
      PPTEFF=PPTEFF+0.65
      PPT=PPT-1.0
      ENDIF
      IF (PPT.LT.1.0) THEN
      PPTEFF=PPTEFF+PPT*0.45
      GO TO 130
      ELSE
      PPTEFF=PPTEFF+0.45
      PPT=PPT-1.0
      ENDIF
      IF (PPT.LT.1.0) THEN
      PPTEFF=PPTEFF+PPT*0.25
      GO TO 130
      ELSE
      PPTEFF=PPTEFF+0.25
      PPT=PPT-1.0
      ENDIF
      PPTEFF=PPTEFF+PPT*0.05
 130  CONTINUE
      PPTEFF=PPTEFF/12.0
      RO=RUSER-PPTEFF
C
C     WATER INFILTRATED INTO SOILS FOR USER
C
      APPLY=DUSER*(1.0-CLOSS)+PUSER
      TAIL=TAILF*APPLY
      APPLY=APPLY-TAIL
      APPLY=APPLY/AREA
C
C     SOIL MOISTURE WHERE ET CURVE BREAKS
C
      THETAG=GAMMA*THAWC
C
C     DIVIDE FIELD INTO FIVE ZONES
C
      PET=ETUSER
      DS=0.0
      DP=0.0
      ET=0.0
      DO 140 IZONE=1,5
C
C     APPLIED WATER TO ZONE
C
      UC=UCOEF
      IF (UCOEF.LT.0.4) UC=0.4
      AFAC=1.0 + ((1.0-UC)*5.0)*((3-IZONE)/6.0)
      AWAT=APPLY*AFAC
      AWAT=AWAT+PPTEFF
C
C     COMPUTE EVAPOTRANSPIRATION FOR CASE OF APPLIED WATER
C        GREATER THAN PET
C
      THETAI=THETA(IUSER,IZONE)
      IF (AWAT.GE.PET) THEN
      DELTH=(AWAT-PET)/ROOT
      THETAF=THETAI+DELTH
      DRAIN=0.0
      IF (THETAF.GT.THAWC) THEN
      DRAIN=(THETAF-THAWC)*ROOT
      THETAF=THAWC
      DELTH=THETAF-THETAI
      ENDIF
      ET=ET+PET
      DP=DP+DRAIN
      DS=DS+DELTH*ROOT
      GO TO 135
      ENDIF
C
C     COMPUTE EVAPOTRANSPIRATION FOR CASE OF APPLIED WATER
C        LESS THAN PET
C
      IF (AWAT.LT.PET) THEN
      ASTORE=0.0
      IF (THETAI.GT.THETAG) ASTORE=(THETAI-THETAG)*ROOT
C
C     ALL ET AT PET RATE
C
      IF (AWAT+ASTORE.GE.PET) THEN
      DELTH=(AWAT-PET)/ROOT
      THETAF=THETAI+DELTH
      DRAIN=0.0
      ET=ET+PET
      DP=DP+DRAIN
      DS=DS+DELTH*ROOT
      GO TO 135
      ENDIF
C
C     ONLY SOME ET AT PET RATE
C
      IF (AWAT+ASTORE.LT.PET) THEN
      DELT=1.0-(AWAT+ASTORE)/PET
      XTHETA=THETAG
      IF (THETAI.LT.THETAG) XTHETA=THETAI
      THETAF=XTHETA+XTHETA*(EXP(-PET*DELT/(ROOT*THETAG))-1.0)
      DELTH=THETAF-THETAI
      DRAIN=0.0
      ET=ET+AWAT+ASTORE-(THETAF-XTHETA)*ROOT
      DP=DP+DRAIN
      DS=DS+DELTH*ROOT
      GO TO 135
      ENDIF
      ENDIF
 135  CONTINUE
      THETA(IUSER,IZONE)=THETAF
 140  CONTINUE
C
C     AVERAGE OVER FIVE ZONES
C
      ET=ET/5.0
      DP=DP/5.0
      DS=DS/5.0
      RECH=DP*AREA+CLOSS*DUSER
      EVAP=ET*AREA
C
C     WATER BUDGET FOR LAND-SURFACE SYSTEM
C
      XET=XET+ET*AREA
      XDP=XDP+RECH
      XDS=XDS+DS*AREA
      XPPT=XPPT+RUSER*AREA
      XCANAL=XCANAL+DUSER
      XPUMP=XPUMP+PUSER
      XTAIL=XTAIL+TAIL
      XRO=XRO+RO*AREA
      IF (IUSER.EQ.NUSER) THEN
      XRES=XPUMP+XCANAL+XPPT-XTAIL-XRO-XET-XDP-XDS
      SXRES=SXRES+XRES
      IF (IOUT.EQ.1) THEN
      ENDIF
      ENDIF
 900  FORMAT(/1X,'LAND WATER BUDGET'/1X,17('-')/
     1   1X,'TIME STEP                 ',I10/
     2   1X,'PUMPING TO USERS          ',F10.2/
     3   1X,'CANAL DELIVERIES TO USERS ',F10.2/
     4   1X,'PRECIPITATION             ',F10.2/
     5   1X,'TAIL WATER FROM FIELDS    ',F10.2/
     6   1X,'RUNOFF                    ',F10.2/
     7   1X,'EVAPOTRANSPIRATION        ',F10.2/
     8   1X,'DEEP PERCOLATION          ',F10.2/
     9   1X,'MOISTURE STORAGE CHANGE   ',F10.2/
     1   1X,'RESIDUAL                  ',F10.2/
     2   1X,'CUMULATIVE RESIDUAL       ',F10.2)
      RETURN
      END